summaryrefslogtreecommitdiffstats
path: root/kpresenter/KPrDocument.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpresenter/KPrDocument.h')
-rw-r--r--kpresenter/KPrDocument.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/kpresenter/KPrDocument.h b/kpresenter/KPrDocument.h
index c51060a4..e1ae80e3 100644
--- a/kpresenter/KPrDocument.h
+++ b/kpresenter/KPrDocument.h
@@ -236,11 +236,11 @@ class KPrDocument : public KoDocument
void deletePage( int _page );
void copyPageToClipboard( int pgnum );
- // tqrepaint all views
- void tqrepaint( bool );
+ // repaint all views
+ void repaint( bool );
- void tqrepaint( const TQRect& );
- void tqrepaint( KPrObject* );
+ void repaint( const TQRect& );
+ void repaint( KPrObject* );
// stuff for screen-presentations
/**
@@ -552,7 +552,7 @@ protected:
void testAndCloseAllTextObjectProtectedContent();
// ************ functions ************
/**
- * Overloaded function from @ref Document_impl. Saves all tqchildren.
+ * Overloaded function from @ref Document_impl. Saves all children.
*/
virtual bool saveChildren( KoStore* _store );
@@ -707,8 +707,8 @@ private:
KPrLoadingInfo *m_loadingInfo;
TQValueList<int> *m_customListTest;
- /// here the amount of existing tqchildren before inserting a page/file
- /// is saved, so that we load the correct tqchildren
+ /// here the amount of existing children before inserting a page/file
+ /// is saved, so that we load the correct children
int m_childCountBeforeInsert;
};